#!/usr/bin/env python

import setuptools

setuptools.setup(
        version='1.0',
        name='cmdjudge',
        description='bash script for offline code judge',
        author='Pradeep Khileri',
        author_email='pradeepchoudhary009@gmail.com',
        license='MIT',
        url='https://github.com/prdpx7/cmdjudge',
        scripts=['cmdjudge'],
        )
